EXPORTS
	?ShowToolTip@SDrawUtils@@SAXPAVCAknInfoPopupNoteController@@PAVCCoeControl@@VTPoint@@W4TGulAlignmentValue@@ABVTDesC16@@@Z @ 1 NONAME ; void SDrawUtils::ShowToolTip(class CAknInfoPopupNoteController *, class CCoeControl *, class TPoint, enum TGulAlignmentValue, class TDesC16 const &)
	?LaunchExitWithoutSavingQueryL@CImageEditorUIView@@QBEHXZ @ 2 NONAME ; int CImageEditorUIView::LaunchExitWithoutSavingQueryL(void) const
	?SetSliderPosition@CSingleParamControl@@QAEXH@Z @ 3 NONAME ; void CSingleParamControl::SetSliderPosition(int)
	?LaunchProgressNoteL@SDrawUtils@@SAXPAPAVCAknProgressDialog@@HABVTDesC16@@HPAVMProgressDialogCallback@@@Z @ 4 NONAME ; void SDrawUtils::LaunchProgressNoteL(class CAknProgressDialog * *, int, class TDesC16 const &, int, class MProgressDialogCallback *)
	?IsMemoryInCriticalLevel@CImageEditorUIView@@QAEHXZ @ 5 NONAME ; int CImageEditorUIView::IsMemoryInCriticalLevel(void)
	?GetTouchPanDirections@CImageEditorUIView@@QAEXAAH0@Z @ 6 NONAME ; void CImageEditorUIView::GetTouchPanDirections(int &, int &)
	?CountComponentControls@CImageEditorControlBase@@UBEHXZ @ 7 NONAME ; int CImageEditorControlBase::CountComponentControls(void) const
	?SetCaption@CSingleParamControl@@QAEXABVTDesC16@@@Z @ 8 NONAME ; void CSingleParamControl::SetCaption(class TDesC16 const &)
	?LaunchLoadWaitDialogL@CImageEditorUIView@@QBEXPAPAVCAknWaitDialog@@PAVMProgressDialogCallback@@@Z @ 9 NONAME ; void CImageEditorUIView::LaunchLoadWaitDialogL(class CAknWaitDialog * *, class MProgressDialogCallback *) const
	?LaunchListQueryDialogL@SDrawUtils@@SAHPAVMDesC16Array@@ABVTDesC16@@@Z @ 10 NONAME ; int SDrawUtils::LaunchListQueryDialogL(class MDesC16Array *, class TDesC16 const &)
	??0CImageEditorControlBase@@QAE@XZ @ 11 NONAME ; CImageEditorControlBase::CImageEditorControlBase(void)
	?GetDimmedMenuItems@CImageEditorControlBase@@UAE?AVTBitField@@XZ @ 12 NONAME ; class TBitField CImageEditorControlBase::GetDimmedMenuItems(void)
	?Draw@CSingleParamControl@@EBEXABVTRect@@@Z @ 13 NONAME ; void CSingleParamControl::Draw(class TRect const &) const
	?DoDeactivate@CImageEditorUIView@@EAEXXZ @ 14 NONAME ; void CImageEditorUIView::DoDeactivate(void)
	?LaunchColorSelectionGridL@SDrawUtils@@SAHAAVTRgb@@@Z @ 15 NONAME ; int SDrawUtils::LaunchColorSelectionGridL(class TRgb &)
	?ResetBusy@CImageEditorUIView@@QAEXXZ @ 16 NONAME ; void CImageEditorUIView::ResetBusy(void)
	?ResetFullScreen@CImageEditorUIView@@QAEXXZ @ 17 NONAME ; void CImageEditorUIView::ResetFullScreen(void)
	?Id@CImageEditorUIView@@UBE?AVTUid@@XZ @ 18 NONAME ; class TUid CImageEditorUIView::Id(void) const
	?SetTitlePaneTextL@CImageEditorUIView@@QAEXABVTDesC16@@@Z @ 19 NONAME ; void CImageEditorUIView::SetTitlePaneTextL(class TDesC16 const &)
	?CountImageSizesAndPositions@CSingleParamControl@@AAEXXZ @ 20 NONAME ; void CSingleParamControl::CountImageSizesAndPositions(void)
	?SizeChanged@CSingleParamControl@@UAEXXZ @ 21 NONAME ; void CSingleParamControl::SizeChanged(void)
	?NewL@CSingleParamControl@@SAPAV1@ABVTRect@@PAVCCoeControl@@H@Z @ 22 NONAME ; class CSingleParamControl * CSingleParamControl::NewL(class TRect const &, class CCoeControl *, int)
	?ComponentControl@CImageEditorControlBase@@UBEPAVCCoeControl@@H@Z @ 23 NONAME ; class CCoeControl * CImageEditorControlBase::ComponentControl(int) const
	?LaunchColorSelectionPopupL@SDrawUtils@@SAHPBVCFbsBitmap@@VTRect@@AAVTRgb@@@Z @ 24 NONAME ; int SDrawUtils::LaunchColorSelectionPopupL(class CFbsBitmap const *, class TRect, class TRgb &)
	?GetNaviPaneTextL@CImageEditorControlBase@@UAE?AVTPtrC16@@AAH0@Z @ 25 NONAME ; class TPtrC16 CImageEditorControlBase::GetNaviPaneTextL(int &, int &)
	?OfferKeyEventL@CSingleParamControl@@UAE?AW4TKeyResponse@@ABUTKeyEvent@@W4TEventCode@@@Z @ 26 NONAME ; enum TKeyResponse CSingleParamControl::OfferKeyEventL(struct TKeyEvent const &, enum TEventCode)
	?ResetBusy@CImageEditorControlBase@@UAEXXZ @ 27 NONAME ; void CImageEditorControlBase::ResetBusy(void)
	??1CMultiLineQueryDialog@@UAE@XZ @ 28 NONAME ; CMultiLineQueryDialog::~CMultiLineQueryDialog(void)
	?SetMiddleSoftKeyL@CImageEditorUIView@@QAEXABVTDesC16@@H@Z @ 29 NONAME ; void CImageEditorUIView::SetMiddleSoftKeyL(class TDesC16 const &, int)
	?HandlePluginCommandL@CSingleParamControl@@UAEXH@Z @ 30 NONAME ; void CSingleParamControl::HandlePluginCommandL(int)
	?DrawBeveledRect@SDrawUtils@@SAXAAVCGraphicsContext@@ABVTRect@@ABVTRgb@@22@Z @ 31 NONAME ; void SDrawUtils::DrawBeveledRect(class CGraphicsContext &, class TRect const &, class TRgb const &, class TRgb const &, class TRgb const &)
	?OfferKeyEventL@CMultiLineQueryDialog@@UAE?AW4TKeyResponse@@ABUTKeyEvent@@W4TEventCode@@@Z @ 32 NONAME ; enum TKeyResponse CMultiLineQueryDialog::OfferKeyEventL(struct TKeyEvent const &, enum TEventCode)
	?ClearTitlePaneTextL@CImageEditorUIView@@QAEXXZ @ 33 NONAME ; void CImageEditorUIView::ClearTitlePaneTextL(void)
	?SetSoftKey2L@CImageEditorUIView@@QAEXABVTDesC16@@H@Z @ 34 NONAME ; void CImageEditorUIView::SetSoftKey2L(class TDesC16 const &, int)
	??1CImageEditorUIView@@UAE@XZ @ 35 NONAME ; CImageEditorUIView::~CImageEditorUIView(void)
	?GetNaviPaneTextL@CSingleParamControl@@UAE?AVTPtrC16@@AAH0@Z @ 36 NONAME ; class TPtrC16 CSingleParamControl::GetNaviPaneTextL(int &, int &)
	??1CPreviewControlBase@@UAE@XZ @ 37 NONAME ; CPreviewControlBase::~CPreviewControlBase(void)
	?LaunchQueryDialogL@SDrawUtils@@SAHABVTDesC16@@@Z @ 38 NONAME ; int SDrawUtils::LaunchQueryDialogL(class TDesC16 const &)
	?LaunchSaveImageQueryL@CImageEditorUIView@@QBEHXZ @ 39 NONAME ; int CImageEditorUIView::LaunchSaveImageQueryL(void) const
	?ComponentControl@CSingleParamControl@@UBEPAVCCoeControl@@H@Z @ 40 NONAME ; class CCoeControl * CSingleParamControl::ComponentControl(int) const
	?SetView@CImageEditorControlBase@@UAEXPAVCAknView@@@Z @ 41 NONAME ; void CImageEditorControlBase::SetView(class CAknView *)
	?LaunchMultiLineTextQueryDialogL@SDrawUtils@@SAHAAVTDes16@@ABVTDesC16@@@Z @ 42 NONAME ; int SDrawUtils::LaunchMultiLineTextQueryDialogL(class TDes16 &, class TDesC16 const &)
	?ActivatePluginL@CImageEditorUIView@@QAEXPAVCCoeControl@@@Z @ 43 NONAME ; void CImageEditorUIView::ActivatePluginL(class CCoeControl *)
	?CountComponentControls@CSingleParamControl@@UBEHXZ @ 44 NONAME ; int CSingleParamControl::CountComponentControls(void) const
	?SetIcon@CSingleParamControl@@QAEXPAVCEikImage@@@Z @ 45 NONAME ; void CSingleParamControl::SetIcon(class CEikImage *)
	?UpdateLayoutL@CImageEditorUIView@@QBEXH@Z @ 46 NONAME ; void CImageEditorUIView::UpdateLayoutL(int) const
	?MoveSlider@CSingleParamControl@@AAEXH@Z @ 47 NONAME ; void CSingleParamControl::MoveSlider(int)
	?Draw@CPreviewControlBase@@EBEXABVTRect@@@Z @ 48 NONAME ; void CPreviewControlBase::Draw(class TRect const &) const
	?SetNaviPaneTextL@CImageEditorUIView@@QAEXABVTDesC16@@HH@Z @ 49 NONAME ; void CImageEditorUIView::SetNaviPaneTextL(class TDesC16 const &, int, int)
	?HandlePluginCommandL@CImageEditorControlBase@@UAEXH@Z @ 50 NONAME ; void CImageEditorControlBase::HandlePluginCommandL(int)
	?Busy@CImageEditorControlBase@@UBEHXZ @ 51 NONAME ; int CImageEditorControlBase::Busy(void) const
	?HandlePointerEventL@CImageEditorControlBase@@MAEXABUTPointerEvent@@@Z @ 52 NONAME ; void CImageEditorControlBase::HandlePointerEventL(struct TPointerEvent const &)
	?SetSliderStep@CSingleParamControl@@QAEXI@Z @ 53 NONAME ; void CSingleParamControl::SetSliderStep(unsigned int)
	?LaunchWaitDialog@CImageEditorUIView@@QBEXXZ @ 54 NONAME ; void CImageEditorUIView::LaunchWaitDialog(void) const
	?GetContextMenuResourceId@CImageEditorControlBase@@UAEHXZ @ 55 NONAME ; int CImageEditorControlBase::GetContextMenuResourceId(void)
	?DrawPreviewImage@CPreviewControlBase@@UBEXABVTRect@@@Z @ 56 NONAME ; void CPreviewControlBase::DrawPreviewImage(class TRect const &) const
	?HideWaitDialog@CImageEditorUIView@@QBEXXZ @ 57 NONAME ; void CImageEditorUIView::HideWaitDialog(void) const
	?PrepareL@CImageEditorControlBase@@UAEXXZ @ 58 NONAME ; void CImageEditorControlBase::PrepareL(void)
	?LaunchSendQueryL@CImageEditorUIView@@QBEXABVTSendingCapabilities@@AAV?$TBuf@$0BAA@@@@Z @ 59 NONAME ; void CImageEditorUIView::LaunchSendQueryL(class TSendingCapabilities const &, class TBuf<256> &) const
	?ClearNaviPaneTextL@CImageEditorUIView@@QAEXXZ @ 60 NONAME ; void CImageEditorUIView::ClearNaviPaneTextL(void)
	?SetSoftKey1L@CImageEditorUIView@@QAEXABVTDesC16@@H@Z @ 61 NONAME ; void CImageEditorUIView::SetSoftKey1L(class TDesC16 const &, int)
	?SetBusy@CImageEditorUIView@@QAEXXZ @ 62 NONAME ; void CImageEditorUIView::SetBusy(void)
	?Position@CSingleParamControl@@QBEHXZ @ 63 NONAME ; int CSingleParamControl::Position(void) const
	?GetContainer@CImageEditorUIView@@QBEPAVCCoeControl@@XZ @ 64 NONAME ; class CCoeControl * CImageEditorUIView::GetContainer(void) const
	?LaunchSendQueryL@CImageEditorUIView@@QBEXABVTSendingCapabilities@@AAVRFile@@@Z @ 65 NONAME ; void CImageEditorUIView::LaunchSendQueryL(class TSendingCapabilities const &, class RFile &) const
	?LaunchSaveChangesQueryL@CImageEditorUIView@@QBEHXZ @ 66 NONAME ; int CImageEditorUIView::LaunchSaveChangesQueryL(void) const
	?SetImageL@CImageEditorControlBase@@UAEXPAVCFbsBitmap@@@Z @ 67 NONAME ; void CImageEditorControlBase::SetImageL(class CFbsBitmap *)
	?SetSaveFlag@CImageEditorUIView@@QAEXH@Z @ 68 NONAME ; void CImageEditorUIView::SetSaveFlag(int)
	?SetBusy@CImageEditorControlBase@@UAEXXZ @ 69 NONAME ; void CImageEditorControlBase::SetBusy(void)
	?SetView@CSingleParamControl@@UAEXPAVCAknView@@@Z @ 70 NONAME ; void CSingleParamControl::SetView(class CAknView *)
	?HandleStatusPaneSizeChange@CImageEditorUIView@@UAEXXZ @ 71 NONAME ; void CImageEditorUIView::HandleStatusPaneSizeChange(void)
	?DynInitMenuPaneL@CImageEditorUIView@@UAEXHPAVCEikMenuPane@@@Z @ 72 NONAME ; void CImageEditorUIView::DynInitMenuPaneL(int, class CEikMenuPane *)
	?SetImageL@CImageEditorControlBase@@UAEXPBVCFbsBitmap@@@Z @ 73 NONAME ; void CImageEditorControlBase::SetImageL(class CFbsBitmap const *)
	?GetSoftkeyIndexL@CImageEditorControlBase@@UAEHXZ @ 74 NONAME ; int CImageEditorControlBase::GetSoftkeyIndexL(void)
	?AddPluginUiItemL@CImageEditorUIView@@QAEXPBVCPluginInfo@@@Z @ 75 NONAME ; void CImageEditorUIView::AddPluginUiItemL(class CPluginInfo const *)
	??1CColorSelectionGrid@@UAE@XZ @ 76 NONAME ; CColorSelectionGrid::~CColorSelectionGrid(void)
	?SetFullScreen@CImageEditorUIView@@QAEXXZ @ 77 NONAME ; void CImageEditorUIView::SetFullScreen(void)
	?SetUndoFlag@CImageEditorUIView@@QAEXH@Z @ 78 NONAME ; void CImageEditorUIView::SetUndoFlag(int)
	??1CSingleParamControl@@UAE@XZ @ 79 NONAME ; CSingleParamControl::~CSingleParamControl(void)
	?DrawGuide@SDrawUtils@@SAXAAVCGraphicsContext@@ABVTRect@@W4TGuideType@1@ABVTRgb@@@Z @ 80 NONAME ; void SDrawUtils::DrawGuide(class CGraphicsContext &, class TRect const &, enum SDrawUtils::TGuideType, class TRgb const &)
	?InZoomingState@CImageEditorUIView@@QAEHXZ @ 81 NONAME ; int CImageEditorUIView::InZoomingState(void)
	?ShowConfirmationNoteL@CImageEditorUIView@@QBEXABVTDesC16@@@Z @ 82 NONAME ; void CImageEditorUIView::ShowConfirmationNoteL(class TDesC16 const &) const
	?ConstructL@CPreviewControlBase@@UAEXABVTRect@@PAVCCoeControl@@@Z @ 83 NONAME ; void CPreviewControlBase::ConstructL(class TRect const &, class CCoeControl *)
	??0CColorSelectionGrid@@QAE@XZ @ 84 NONAME ; CColorSelectionGrid::CColorSelectionGrid(void)
	??0CSingleParamControl@@QAE@XZ @ 85 NONAME ; CSingleParamControl::CSingleParamControl(void)
	?SetSelectedUiItemL@CSingleParamControl@@UAEXPAVCPluginInfo@@@Z @ 86 NONAME ; void CSingleParamControl::SetSelectedUiItemL(class CPluginInfo *)
	?ConstructL@CImageEditorUIView@@QAEXXZ @ 87 NONAME ; void CImageEditorUIView::ConstructL(void)
	?ConstructL@CColorSelectionGrid@@UAEXPBVCCoeControl@@H@Z @ 88 NONAME ; void CColorSelectionGrid::ConstructL(class CCoeControl const *, int)
	?HandleCommandL@CImageEditorUIView@@UAEXH@Z @ 89 NONAME ; void CImageEditorUIView::HandleCommandL(int)
	?SetSliderMinimumAndMaximum@CSingleParamControl@@QAEXHH@Z @ 90 NONAME ; void CSingleParamControl::SetSliderMinimumAndMaximum(int, int)
	?ViewScreenModeCompatible@CImageEditorUIView@@MAEHH@Z @ 91 NONAME ; int CImageEditorUIView::ViewScreenModeCompatible(int)
	?SizeChanged@CImageEditorControlBase@@MAEXXZ @ 92 NONAME ; void CImageEditorControlBase::SizeChanged(void)
	?SetImageL@CImageEditorUIView@@QAEXPAVCFbsBitmap@@@Z @ 93 NONAME ; void CImageEditorUIView::SetImageL(class CFbsBitmap *)
	??0CImageEditorUIView@@QAE@XZ @ 94 NONAME ; CImageEditorUIView::CImageEditorUIView(void)
	?LaunchTextQueryDialogL@SDrawUtils@@SAHAAVTDes16@@ABVTDesC16@@@Z @ 95 NONAME ; int SDrawUtils::LaunchTextQueryDialogL(class TDes16 &, class TDesC16 const &)
	?HandleClientRectChange@CImageEditorUIView@@QAEXXZ @ 96 NONAME ; void CImageEditorUIView::HandleClientRectChange(void)
	??1CImageEditorControlBase@@UAE@XZ @ 97 NONAME ; CImageEditorControlBase::~CImageEditorControlBase(void)
	?DoActivateL@CImageEditorUIView@@EAEXABVTVwsViewId@@VTUid@@ABVTDesC8@@@Z @ 98 NONAME ; void CImageEditorUIView::DoActivateL(class TVwsViewId const &, class TUid, class TDesC8 const &)
	??0CMultiLineQueryDialog@@AAE@AAVTDes16@@ABW4TTone@CAknQueryDialog@@@Z @ 99 NONAME ; CMultiLineQueryDialog::CMultiLineQueryDialog(class TDes16 &, enum CAknQueryDialog::TTone const &)
	?IsDrawPlugin@CImageEditorUIContainer@@QAEXH@Z @ 100 NONAME ; void CImageEditorUIContainer::IsDrawPlugin(int)
	?OfferKeyEventL@CImageEditorControlBase@@UAE?AW4TKeyResponse@@ABUTKeyEvent@@W4TEventCode@@@Z @ 101 NONAME ; enum TKeyResponse CImageEditorControlBase::OfferKeyEventL(struct TKeyEvent const &, enum TEventCode)
	?GetSoftkeyIndexL@CSingleParamControl@@UAEHXZ @ 102 NONAME ; int CSingleParamControl::GetSoftkeyIndexL(void)
	?LaunchSaveWaitDialogL@CImageEditorUIView@@QBEXPAPAVCAknProgressDialog@@HPAVMProgressDialogCallback@@@Z @ 103 NONAME ; void CImageEditorUIView::LaunchSaveWaitDialogL(class CAknProgressDialog * *, int, class MProgressDialogCallback *) const
	?SetImageL@CPreviewControlBase@@UAEXPAVCFbsBitmap@@@Z @ 104 NONAME ; void CPreviewControlBase::SetImageL(class CFbsBitmap *)
	?SetParObserver@CSingleParamControl@@QAEXPAVMSingleParControlObserver@@@Z @ 105 NONAME ; void CSingleParamControl::SetParObserver(class MSingleParControlObserver *)
	?NewL@CPreviewControlBase@@SAPAV1@ABVTRect@@PAVCCoeControl@@@Z @ 106 NONAME ; class CPreviewControlBase * CPreviewControlBase::NewL(class TRect const &, class CCoeControl *)
	?HandlePointerEventL@CSingleParamControl@@UAEXABUTPointerEvent@@@Z @ 107 NONAME ; void CSingleParamControl::HandlePointerEventL(struct TPointerEvent const &)
	?NewL@CMultiLineQueryDialog@@SAPAV1@AAVTDes16@@ABW4TTone@CAknQueryDialog@@@Z @ 108 NONAME ; class CMultiLineQueryDialog * CMultiLineQueryDialog::NewL(class TDes16 &, enum CAknQueryDialog::TTone const &)
	?DrawFlatRect@SDrawUtils@@SAXAAVCGraphicsContext@@ABVTRect@@ABVTRgb@@22@Z @ 109 NONAME ; void SDrawUtils::DrawFlatRect(class CGraphicsContext &, class TRect const &, class TRgb const &, class TRgb const &, class TRgb const &)
	?Draw@CImageEditorControlBase@@EBEXABVTRect@@@Z @ 110 NONAME ; void CImageEditorControlBase::Draw(class TRect const &) const
	?LaunchCancelTextInputQueryL@CImageEditorUIView@@QBEHXZ @ 111 NONAME ; int CImageEditorUIView::LaunchCancelTextInputQueryL(void) const
	?SetImageL@CPreviewControlBase@@UAEXPBVCFbsBitmap@@@Z @ 112 NONAME ; void CPreviewControlBase::SetImageL(class CFbsBitmap const *)
	?SetImageFileName@CImageEditorUIView@@QAEXABVTDesC16@@@Z @ 113 NONAME ; void CImageEditorUIView::SetImageFileName(class TDesC16 const &)
	?ShowInformationNoteL@CImageEditorUIView@@QBEXABVTDesC16@@@Z @ 114 NONAME ; void CImageEditorUIView::ShowInformationNoteL(class TDesC16 const &) const
	?ConstructL@CImageEditorControlBase@@UAEXABVTRect@@PAVCCoeControl@@@Z @ 115 NONAME ; void CImageEditorControlBase::ConstructL(class TRect const &, class CCoeControl *)
	?LaunchWaitNoteL@SDrawUtils@@SAXPAPAVCAknWaitDialog@@HABVTDesC16@@PAVMProgressDialogCallback@@@Z @ 116 NONAME ; void SDrawUtils::LaunchWaitNoteL(class CAknWaitDialog * *, int, class TDesC16 const &, class MProgressDialogCallback *)
	?SetSelectedUiItemL@CImageEditorControlBase@@UAEXPAVCPluginInfo@@@Z @ 117 NONAME ; void CImageEditorControlBase::SetSelectedUiItemL(class CPluginInfo *)
	?SetSendAppUi@CImageEditorUIView@@QAEXPAVCSendUi@@@Z @ 118 NONAME ; void CImageEditorUIView::SetSendAppUi(class CSendUi *)
	?SetZoomModeL@CImageEditorUIView@@QAEXABW4TZoomMode@@@Z @ 119 NONAME ; void CImageEditorUIView::SetZoomModeL(enum TZoomMode const &)
	?SetCustomButtonsL@CImageEditorUIView@@QBEXH@Z @ 120 NONAME ; void CImageEditorUIView::SetCustomButtonsL(int) const
	?SetSliderStepAmount@CSingleParamControl@@QAEXE@Z @ 121 NONAME ; void CSingleParamControl::SetSliderStepAmount(unsigned char)
	?GetIndicatorBitmapL@SDrawUtils@@SAHAAPAVCFbsBitmap@@0HH@Z @ 122 NONAME ; int SDrawUtils::GetIndicatorBitmapL(class CFbsBitmap * &, class CFbsBitmap * &, int, int)
	?ActivateMainViewL@CImageEditorUIView@@QAEXXZ @ 123 NONAME ; void CImageEditorUIView::ActivateMainViewL(void)
	?GetSelectedPluginInfoL@CImageEditorUIView@@QAEPAVCPluginInfo@@XZ @ 124 NONAME ; class CPluginInfo * CImageEditorUIView::GetSelectedPluginInfoL(void)
	?LaunchQueryDialogOkOnlyL@SDrawUtils@@SAHABVTDesC16@@@Z @ 125 NONAME ; int SDrawUtils::LaunchQueryDialogOkOnlyL(class TDesC16 const &)
	?SizeChanged@CColorSelectionGrid@@MAEXXZ @ 126 NONAME ; void CColorSelectionGrid::SizeChanged(void)
	?ConstructL@CSingleParamControl@@UAEXABVTRect@@PAVCCoeControl@@H@Z @ 127 NONAME ; void CSingleParamControl::ConstructL(class TRect const &, class CCoeControl *, int)
	?ShowToolTip@SDrawUtils@@SAXPAVCAknInfoPopupNoteController@@PAVCCoeControl@@VTRect@@ABVTDesC16@@@Z @ 128 NONAME ; void SDrawUtils::ShowToolTip(class CAknInfoPopupNoteController *, class CCoeControl *, class TRect, class TDesC16 const &)

